

#if !defined __VGEV_TILE_H
#define __VGEV_TILE_H


#include "basic_dt.h"
#include "datatype.h"


class canvas;


/* **************************************************************
	image tile
************************************************************** */
class image_tile_type {

   public:
      string_type filename;
      double swlat, swlon, nelat, nelon;
      int initflag;
      texbase *tob;

      image_tile_type() { tob = NULL; initflag = 0; }
      virtual ~image_tile_type() {};
};


/* **************************************************************
   lod for a set of tiles in a subblock
************************************************************** */
class image_tile_level_type {

   public:
      double dlat, dlon;
      int count;
      image_tile_type *tile;

      image_tile_level_type() { tile = NULL; }
      virtual ~image_tile_level_type() { if (tile) delete [] tile; }
};


/* **************************************************************
   a subblock on a cd
************************************************************** */
class sub_image_block_type : public dbl_llist {

   public:
      string_type basename;   // name of common subblock group of tiles
      double swa, swo, nea, neo;
      int count;
      image_tile_level_type *tile_level;
      int current_level;

      sub_image_block_type() { tile_level = NULL; }
      virtual ~sub_image_block_type() { if (tile_level) delete [] tile_level; }
};


/* **************************************************************
  cd level
************************************************************** */
class image_block_type {

   public:
      string_type basename;  // tile_index filename
      int subcount;
      dbl_llist_manager subblockman;
      
      virtual ~image_block_type() {}

      int parse(FILE *infile, char *token);
      int preprocess();
};


/* **************************************************************
  cd grouping level
************************************************************** */
class lod_type {

   public:
      image_block_type *blocks;
      int count;
      double swap_down, swap_up;

      lod_type() { blocks = NULL; }
      virtual ~lod_type() { if (blocks) delete [] blocks; }

      int parse(FILE *infile, char *token);
      int preprocess();
};


/* **************************************************************
************************************************************** */
class tile_manager_type {

   public:
      int lod_current_level;
      int lod_count;
      lod_type *lods;
      string_type mapname;
      dbl_llist_manager visman;
      dbl_llist_manager pointman;

      tile_manager_type() { lod_count = lod_current_level = 0; lods = NULL; }
      virtual ~tile_manager_type() { if (lods) delete [] lods; }

      void dest();
      int read_tiles(char *filename);
      void render(canvas *tgev);
      void preprocess_map(canvas *tgev);
};


#include "vgev_draw.h"

#endif
