

/* ***********************************************************************
                Naval Air Warfare Center / Aircraft Division              
                        Patuxent Naval Air Station                         
 ========================================================================

        File:           swegstring.c                                         
                                                                        
        Classification: UNCLASSIFIED                                   
                                                                        
        Description:    This file contains the functions, methods, and
			global variables needed to parse the TDB
			
        Written by:	Alex Harper
*********************************************************************** */


#include <stdio.h>
#include "swegstring.h"


/* ***********************************************************
  This is the "tokenizer" - it reads in each sweg token, minus
  comments
*********************************************************** */
int get_sweg_token(FILE *infile, char *x) {

   int errorflag;
   int commentflag;
   double t;

   do {
      errorflag = fscanf(infile, "%lf", &t);
      if (errorflag == EOF)
         return 0;

      if (errorflag) {
         sprintf(x, "%lf", t);
         return 1;
      }

     fscanf(infile, "%255s", x);

      // "$"
      commentflag = (x[0] == '$' && x[1] != '>');

      if (commentflag) {
         while ((errorflag=fgetc(infile)) != '\n')
            if (errorflag == EOF)
               return 0;

         continue;
      }
      
      // "$> ... <$"
      commentflag = (x[0] == '$' && x[1] == '>');
   
      if (commentflag) {   

         errorflag=fgetc(infile);

         while (commentflag) {
            if (errorflag == EOF)
               return 0;

            if (errorflag == '<') {
               errorflag=fgetc(infile);
               commentflag -= (errorflag == '$');
               continue;
            }

            if (errorflag == '$') {
               errorflag=fgetc(infile);
               commentflag += (errorflag == '>');
               continue;
            }
	    
            errorflag=fgetc(infile);
         }
	
         commentflag = 1; 
      }

   } while (commentflag);
    
   return 1;
}



// tokens to look for ...

char TOKEN_END[]        = "END";
char TOKEN_CAPABILITY[] = "CAPABILITY";
char TOKEN_SNR_RCVR[]   = "SNR-RCVR";
char TOKEN_SNR_XMTR[]   = "SNR-XMTR";
char TOKEN_PLATFORM[]   = "PLATFORM";
char TOKEN_PLAYER_STRUCTURE[]	= "PLAYER-STRUCTURE";
char TOKEN_LINKAGES[]   = "LINKAGES";
char TOKEN_COMM_RCVR[]  = "COMM-RCVR";
char TOKEN_COMM_XMTR[]  = "COMM-XMTR";
char TOKEN_ELEMENT[]    = "ELEMENT";
char TOKEN_THINKER[]    = "THINKER";
char TOKEN_MOVER[]      = "MOVER";
char TOKEN_DISRUPTOR[]  = "DISRUPTOR";
char TOKEN_WEAPON[]     = "WEAPON";
char TOKEN_END_TDB[]    = "END-TDB";
char TOKEN_TDB[]        = "TDB";

char TOKEN_PHZP[]       = "(HZ)";
char TOKEN_HZ[]         = "HZ";
char TOKEN_PMHZP[]      = "(MHZ)";
char TOKEN_MHZ[]        = "MHZ";
char TOKEN_PGHZP[]      = "(GHZ)";
char TOKEN_GHZ[]        = "GHZ";

char TOKEN_PDEGP[]      = "(DEG)";
char TOKEN_DEG[]        = "DEG";
char TOKEN_PRADIANSP[]  = "(RADIANS)";
char TOKEN_RADIANS[]    = "RADIANS";

char TOKEN_PDBP[]       = "(DB)";
char TOKEN_DB[]         = "DB";

char TOKEN_PMP[]        = "(M)";
char TOKEN_M[]          = "M";
char TOKEN_PKMP[]       = "(KM)";
char TOKEN_KM[]         = "KM";
char TOKEN_PFTP[]       = "(FT)";
char TOKEN_FT[]         = "FT";
char TOKEN_PFEETP[]     = "(FEET)";
char TOKEN_FEET[]       = "FEET";
char TOKEN_PANGLESP[]   = "(ANGLES)";
char TOKEN_ANGLES[]     = "ANGLES";
char TOKEN_PMILESP[]    = "(MILES)";
char TOKEN_MILES[]      = "MILES";
char TOKEN_PNMP[]       = "(NM)";
char TOKEN_NM[]         = "NM";
char TOKEN_PM2P[]       = "PM2P";
char TOKEN_M2[]         = "M2";
char TOKEN_PWATTSP[]    = "PWATTSP";
char TOKEN_WATTS[]      = "WATTS";

char TOKEN_ANTENNA_PATTERN[]	= "ANTENNA-PATTERN";
char TOKEN_GAIN[]     = "GAIN";
char TOKEN_AZ[]			= "AZ";
char TOKEN_EL[]			= "EL";
char TOKEN_DIMENSION[]		= "DIMENSION";
char TOKEN_FREQ[]     = "FREQ";
char TOKEN_SIGNATURE[]		= "SIGNATURE";
char TOKEN_RCS[]      = "RCS";
char TOKEN_SUSCEPTIBILITY[]	= "SUSCEPTIBILITY";
char TOKEN_ALT_XMIT[] = "ALT-XMIT";
char TOKEN_ALT_RCVR[] = "ALT_RCVR";

char TOKEN_ONE_M2_DETECT_RNG[]	= "ONE-M2-DETECT-RNG";
// char TOKEN_MTI_ATTENUATION[]	= "MTI-ATTENUATION";
// char TOKEN_RCVR_FREQ_LIMITS[]	= "RCVR-FREQ-LIMITS";
// char TOKEN_RCVR_BANDWIDTH[]	= "RCVR-BANDWIDTH";
// char TOKEN_TRANSMISSION_LOSS[]	= "TRANSMISSION-LOSS";
char TOKEN_INTERNAL_LOSS[]	= "INTERNAL-LOSS";
char TOKEN_PEAK_POWER_OUTPUT[]	= "PEAK-POWER-OUTPUT";
char TOKEN_PULSE_REPETITION_FREQ[]	 = "PULSE-REPETITION-FREQ";
char TOKEN_PULSE_WIDTH[]	          = "PULSE-WIDTH";
char TOKEN_DETECTION_SENSITIVITIES[] = "DETECTION-SENSITIVITIES";
char TOKEN_SENSING_THRESHOLD[]	= "SENSING-THRESHOLD";
char TOKEN_RECEIVER_NOISE[]	= "RECEIVER-NOISE";
char TOKEN_INTERNAL_LOSSES[]	= "INTERNAL-LOSSES";
char TOKEN_POST_LOCKON_THRESHOLD[]	= "POST-LOCKON-THRESHOLD";

char TOKEN_REFLECTIVE_EM_SIG_TABLE[]	= "REFLECTIVE-EM-SIG-TABLE";

char TOKEN_SNR_RCVR_FREQS[]      = "SNR-RCVR-FREQS";
char TOKEN_SEARCH[]              = "SEARCH";
char TOKEN_TRACKING[]            = "TRACKING";
char TOKEN_GUIDANCE[]            = "GUIDANCE";
char TOKEN_ACQUISITION[]         = "ACQUISITION";

char TOKEN_SNR_CHARACTERISTICS[] = "SNR-CHARACTERISTICS";
char TOKEN_ACOUSTIC[]            = "ACOUSTIC";
char TOKEN_ELECTRO_MAGNETIC[]    = "ELECTRO-MAGNETIC";
char TOKEN_INFRA_RED[]           = "INFRA-RED";
char TOKEN_RNG_ALT_CAPABILITY[]  = "RNG-ALT-CAPABILITY";
char TOKEN_MIN_ALT[]             = "MIN-ALT";

char TOKEN_SNR_ANGULAR_LIMITS[]  = "SNR-ANGULAR-LIMITS";
char TOKEN_AZ_LIMIT[]            = "AZ-LIMIT";
char TOKEN_EL_LIMIT[]            = "EL-LIMIT";
char TOKEN_LOWER_EL_LIMIT[]      = "LOWER-EL-LIMIT";
char TOKEN_UPPER_EL_LIMIT[]      = "UPPER_EL-LIMIT";

char TOKEN_DUTY_CYCLE[]            = "DUTY-CYCLE";
char TOKEN_PULSE_COMPRESSION_RATIO[] = "PULSE-COMPRESSION-RATIO";
char TOKEN_OPERATING_LOSSES[]      = "OPERATING-LOSSES";
char TOKEN_TRANSMISSION_LOSS[]     = "TRANSMISSION-LOSS";

char TOKEN_EMITTIVE_EM_SIG_TABLE[] = "EMITTIVE-EM-SIG-TABLE";
char TOKEN_PRESENTED_AREA_FREQ[]   = "PRESENTED_AREA_FREQ";
char TOKEN_PIXEL_FIELD_OF_VIEW[]   = "PIXEL-FIELD-OF-VIEW";
char TOKEN_NOISE_EQUIV_IRRADIANCE[] = "NOISE-EQUIV-IRRADIANCE";

char TOKEN_POL[] = "POL";    
char TOKEN_HORIZ_POL[] = "HORIZ-POL";    
char TOKEN_VERT_POL[] = "VERT-POL";       
char TOKEN_LEFT_CIR_POL[] = "LEFT-CIR-POL";
char TOKEN_RIGHT_CIR_POL[] = "RIGHT-CIR-POL";              
char TOKEN_DEFAULT[] = "DEFAULT";
