

#include <string.h>


#include "pstring.h"

#include "vissim.h"


#define TOKEN_FLTFILE_STR		"fltfile"
#define TOKEN_ICONFILE_STR		"iconfile"
#define TOKEN_ROTOR_STR                 "rotor"
#define TOKEN_SEMCODE_STR		"semcode"
#define TOKEN_TRAIL_OFFSET_STR		"trail_offset"
#define TOKEN_DAMAGE_OFFSET_STR	 	"damage_offset"
#define TOKEN_MISSILE_FLAME_JET_STR	"missile_flame_jet"

#define TOKEN_SFX_MOVING_STR		"sfx_moving"
#define TOKEN_SFX_IDLE_STR		"sfx_idle"

#define TOKEN_AUTO_IDLE_STR			"auto_idle"
#define TOKEN_TANK_MOVING_STR			"tank_moving"
#define TOKEN_APC_MOVING_STR			"apc_moving"
#define TOKEN_JET_IDLE_STR			"jet_idle"
#define TOKEN_JET_MOVING_STR			"jet_moving"
#define TOKEN_PROP_IDLE_STR			"prop_idle"
#define TOKEN_PROP_MOVING_STR			"prop_moving"
#define TOKEN_HELICOPTOR_LIGHT_IDLE_STR		"helicoptor_light_idle"
#define TOKEN_HELICOPTOR_LIGHT_MOVING_STR	"helicoptor_light_moving"
#define TOKEN_HELICOPTOR_HEAVY_IDLE_STR		"helicoptor_heavy_idle"
#define TOKEN_HELICOPTOR_HEAVY_MOVING_STR	"helicoptor_heavy_moving"

#define SFX_AUTO_IDLE			0
#define SFX_TANK_MOVING			1
#define SFX_APC_MOVING			2
#define SFX_JET_IDLE			3
#define SFX_JET_MOVING			4
#define SFX_PROP_IDLE			5
#define SFX_PROP_MOVING			6
#define SFX_HELICOPTOR_LIGHT_IDLE	7
#define SFX_HELICOPTOR_LIGHT_MOVING	8
#define SFX_HELICOPTOR_HEAVY_IDLE	9
#define SFX_HELICOPTOR_HEAVY_MOVING	10


/* **************************************************************
************************************************************** */
symbol_correlation_type::symbol_correlation_type() {

   sym_id = 0;
   sym_3D = 0;
   sym_2D = 0;
   sym_2D_color[0] = sym_2D_color[1] = sym_2D_color[2] = sym_2D_color[3] = 0;
   sym_sds = 0;
   burst_warhead = 0;
   burst_fuze = 0;
   burst_quantity = 1;
   burst_rate = 1;
}


/* **************************************************************
************************************************************** */
correlate *correlate::find(int code) {

   if (code == keycode)
      return this;

   return (next) ? ((correlate *)next)->find(code) : NULL;
}


/* **************************************************************
  This contructor correlates a semantic correlation code w/ 3D objects and
  special F/X
************************************************************** */
correlate::correlate(FILE *infile, char *token) {

   keycode = 0;
   fx_flag = FX_FLAG_NULL;
   num_rotors=0;
   
   // current contents of token ignored - contains type (irrelevent)
   
   get_token(infile, token);	// "}"

   while (get_token(infile, token) && token[0] != '}') {

      lower_case(token);

      if (!strcmp(token, TOKEN_FLTFILE_STR)) {
         get_token(infile, token);
         objname.stringcpy(token);
         continue;
      }
      
      if (!strcmp(token, TOKEN_ROTOR_STR)) {
         get_token(infile, token);
         rotor[num_rotors].state.xyz[0] = atof(token);
         get_token(infile, token);
         rotor[num_rotors].state.xyz[1] = atof(token);
         get_token(infile, token);
         rotor[num_rotors].state.xyz[2] = atof(token);
         get_token(infile, token);
         rotor[num_rotors].state.hpr[0] = atof(token);
         get_token(infile, token);
         rotor[num_rotors].state.hpr[1] = atof(token);
         get_token(infile, token);
         rotor[num_rotors].state.hpr[2] = atof(token);
         get_token(infile, token);
	 
         rotor[num_rotors].state.scale = atof(token);
         get_token(infile, token);
         rotor[num_rotors].count = atoi(token);

         num_rotors = (num_rotors + 1) & 0x0f;
         fx_flag |= FX_FLAG_ROTORS;

         continue;
      }
      
      if (!strcmp(token, TOKEN_SEMCODE_STR)) {
         get_token(infile, token);
         keycode = atoi(token);
         continue;
      }
      
      if (!strcmp(token, TOKEN_TRAIL_OFFSET_STR)) {
         get_token(infile, token);
         trail.xyz[0] = atof(token);
         get_token(infile, token);
         trail.xyz[1] = atof(token);
         get_token(infile, token);
         trail.xyz[2] = atof(token);

         trail.hpr[0] = trail.hpr[1] = trail.hpr[2] = 0;

         trail.scale = 1.0f;
	 
         fx_flag |= FX_FLAG_TRAIL;

         continue;
      }
      
      if (!strcmp(token, TOKEN_DAMAGE_OFFSET_STR)) {
         get_token(infile, token);
         damage.xyz[0] = atof(token);
         get_token(infile, token);
         damage.xyz[1] = atof(token);
         get_token(infile, token);
         damage.xyz[2] = atof(token);

         get_token(infile, token);
         damage.hpr[0] = atof(token);
         get_token(infile, token);
         damage.hpr[1] = atof(token);
         get_token(infile, token);
         damage.hpr[2] = atof(token);

         get_token(infile, token);
         damage.scale = atof(token);

         fx_flag |= FX_FLAG_DAMAGE;

         continue;
      }

      if (!strcmp(token, TOKEN_MISSILE_FLAME_JET_STR)) {
         fx_flag |= FX_FLAG_MISSILE_FLAME_JET;
	 continue;
      }
      
      if (!strcmp(token, TOKEN_SFX_IDLE_STR)) {
         get_token(infile, token);
         lower_case(token);
	 
         if (!strcmp(token, TOKEN_AUTO_IDLE_STR))
            sfx_idle_id = SFX_AUTO_IDLE;	 
         else if (!strcmp(token, TOKEN_JET_IDLE_STR))
            sfx_idle_id = SFX_JET_IDLE;	 
         else if (!strcmp(token, TOKEN_PROP_IDLE_STR))
            sfx_idle_id = SFX_PROP_IDLE;	 
         else if (!strcmp(token, TOKEN_HELICOPTOR_LIGHT_IDLE_STR))
            sfx_idle_id = SFX_HELICOPTOR_LIGHT_IDLE;	 
         else if (!strcmp(token, TOKEN_HELICOPTOR_HEAVY_IDLE_STR))
            sfx_idle_id = SFX_HELICOPTOR_HEAVY_IDLE;	 
         else
	    continue;
	 
         fx_flag |= FX_FLAG_SFX_IDLE;
	 continue;
      }
      
      if (!strcmp(token, TOKEN_SFX_MOVING_STR)) {
         get_token(infile, token);
         lower_case(token);

         if (!strcmp(token, TOKEN_TANK_MOVING_STR))
            sfx_moving_id = SFX_TANK_MOVING;	 
         else if (!strcmp(token, TOKEN_APC_MOVING_STR))
            sfx_moving_id = SFX_APC_MOVING;	 
         else if (!strcmp(token, TOKEN_JET_MOVING_STR))
            sfx_moving_id = SFX_JET_MOVING;	 
         else if (!strcmp(token, TOKEN_PROP_MOVING_STR))
            sfx_moving_id = SFX_PROP_MOVING;	 
         else if (!strcmp(token, TOKEN_HELICOPTOR_LIGHT_MOVING_STR))
            sfx_moving_id = SFX_HELICOPTOR_LIGHT_MOVING;	 
         else if (!strcmp(token, TOKEN_HELICOPTOR_HEAVY_MOVING_STR))
            sfx_moving_id = SFX_HELICOPTOR_HEAVY_MOVING;	 
         else
	    continue;
         
         fx_flag |= FX_FLAG_SFX_MOVING;
	 continue;
      }
      
      printf("Warning: Bad Token \"%s\"\n", token);
   }
   
}

